require 'spec_helper'

RSpec.describe Gannet::WebServices do
  describe '.forecast_zip_code' do
    let(:query) do
      {
        format: 'application/json',
        zipCode: 94118
      }
    end

    let(:forecast_zip_code_response) do
      double(
        code: 200,
        parsed_response: [
          {
            'DateIssue' => '2020-10-10 ',
            'DateForecast' => '2020-10-11 ',
            'ReportingArea' => 'San Francisco',
            'StateCode' => 'CA',
            'Latitude' => 37.75,
            'Longitude' => -122.43,
            'ParameterName' => 'PM2.5',
            'AQI' => 89,
            'Category' => {
              'Number' => 2,
              'Name' => 'Moderate'
            },
            'ActionDay' => false
          }
        ]
      )
    end

    before do
      allow(HTTParty).to receive(:get).
        and_return(forecast_zip_code_response)

      Gannet.configure { |c| c.api_key = 'mock_api_key' }
    end

    it 'returns the current forecaset by zip code' do
      expect(HTTParty).to receive(:get).
        with(
          "#{Gannet.configuration.url}/aq/forecast/zipCode",
          query: query.merge(API_KEY: Gannet.configuration.api_key)
        ).
        and_return(forecast_zip_code_response)

      Gannet::WebServices.forecast_zip_code(query)
    end
  end
end
